// This file is generated by kconfig_compiler_kf6 from classifyconfig.kcfg.
// All changes you do to this file will be lost.
#ifndef KLEO_CLASSIFYCONFIG_H
#define KLEO_CLASSIFYCONFIG_H

#include "kleo_export.h"

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

namespace Kleo {

class KLEO_EXPORT ClassifyConfig : public KConfigSkeleton
{
  public:

    ClassifyConfig( );
    ~ClassifyConfig() override;

    /**
      Set Treat p7m files without additional extensions as emails
    */
    void setP7mWithoutExtensionAreEmail( bool v )
    {
      if (!isP7mWithoutExtensionAreEmailImmutable())
        mP7mWithoutExtensionAreEmail = v;
    }

    /**
      Get Treat p7m files without additional extensions as emails
    */
    bool p7mWithoutExtensionAreEmail() const
    {
      return mP7mWithoutExtensionAreEmail;
    }

    /**
      Is Treat p7m files without additional extensions as emails Immutable
    */
    bool isP7mWithoutExtensionAreEmailImmutable() const
    {
      return isImmutable( QStringLiteral( "p7mWithoutExtensionAreEmail" ) );
    }

    /**
      Get Treat p7m files without additional extensions as emails default value
    */
    bool defaultP7mWithoutExtensionAreEmailValue() const
    {
        return defaultP7mWithoutExtensionAreEmailValue_helper();
    }

  protected:

    // General
    bool mP7mWithoutExtensionAreEmail;
    bool defaultP7mWithoutExtensionAreEmailValue_helper() const;
};

}

#endif

